@@ -4,7 +4,6 @@ import functools
 from .config import config
 from .helper import urljoin
 from oauthlib.oauth2 import TokenExpiredError
-from requests import Response
 from requests_oauthlib import OAuth2Session
 import pytz
 import numbers
@@ -49,6 +48,10 @@ class SmappeeApi(object):
             token_updater=token_updater,
         )
 
+    @property
+    def farm(self):
+        return self._farm
+
     @property
     def headers(self):
         return {"Authorization": f"Bearer {self._oauth.access_token}"}
